summaryrefslogtreecommitdiffstats
path: root/tdecachegrind
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:49 -0600
commitf8069e2ea048f2657cc417d83820576ec55c181b (patch)
treecbc5bf540866934a91e0f33b260fc7a25e191fad /tdecachegrind
parente6aaa3624cc6179b82a9bfff1760e742a669064c (diff)
downloadtdesdk-f8069e2ea048f2657cc417d83820576ec55c181b.tar.gz
tdesdk-f8069e2ea048f2657cc417d83820576ec55c181b.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'tdecachegrind')
-rw-r--r--tdecachegrind/tdecachegrind/callgraphview.cpp8
-rw-r--r--tdecachegrind/tdecachegrind/callgraphview.h4
-rw-r--r--tdecachegrind/tdecachegrind/callmapview.cpp8
-rw-r--r--tdecachegrind/tdecachegrind/callmapview.h4
-rw-r--r--tdecachegrind/tdecachegrind/configuration.cpp20
-rw-r--r--tdecachegrind/tdecachegrind/configuration.h6
-rw-r--r--tdecachegrind/tdecachegrind/instrview.cpp8
-rw-r--r--tdecachegrind/tdecachegrind/instrview.h4
-rw-r--r--tdecachegrind/tdecachegrind/multiview.cpp8
-rw-r--r--tdecachegrind/tdecachegrind/multiview.h4
-rw-r--r--tdecachegrind/tdecachegrind/partselection.cpp4
-rw-r--r--tdecachegrind/tdecachegrind/partselection.h6
-rw-r--r--tdecachegrind/tdecachegrind/tabview.cpp8
-rw-r--r--tdecachegrind/tdecachegrind/tabview.h4
-rw-r--r--tdecachegrind/tdecachegrind/toplevel.cpp60
-rw-r--r--tdecachegrind/tdecachegrind/toplevel.h4
-rw-r--r--tdecachegrind/tdecachegrind/traceitemview.cpp20
-rw-r--r--tdecachegrind/tdecachegrind/traceitemview.h20
-rw-r--r--tdecachegrind/tdecachegrind/treemap.cpp4
-rw-r--r--tdecachegrind/tdecachegrind/treemap.h6
20 files changed, 105 insertions, 105 deletions
diff --git a/tdecachegrind/tdecachegrind/callgraphview.cpp b/tdecachegrind/tdecachegrind/callgraphview.cpp
index 9db08a7b..12da360b 100644
--- a/tdecachegrind/tdecachegrind/callgraphview.cpp
+++ b/tdecachegrind/tdecachegrind/callgraphview.cpp
@@ -2685,10 +2685,10 @@ TQString CallGraphView::zoomPosString(ZoomPosition p)
return TQString("TopLeft");
}
-void CallGraphView::readViewConfig(KConfig* c,
+void CallGraphView::readViewConfig(TDEConfig* c,
TQString prefix, TQString postfix, bool)
{
- KConfigGroup* g = configGroup(c, prefix, postfix);
+ TDEConfigGroup* g = configGroup(c, prefix, postfix);
if (0) tqDebug("CallGraphView::readViewConfig");
@@ -2709,10 +2709,10 @@ void CallGraphView::readViewConfig(KConfig* c,
delete g;
}
-void CallGraphView::saveViewConfig(KConfig* c,
+void CallGraphView::saveViewConfig(TDEConfig* c,
TQString prefix, TQString postfix, bool)
{
- KConfigGroup g(c, (prefix+postfix).ascii());
+ TDEConfigGroup g(c, (prefix+postfix).ascii());
writeConfigEntry(&g, "MaxCaller", _maxCallerDepth, DEFAULT_MAXCALLER);
writeConfigEntry(&g, "MaxCalling", _maxCallingDepth, DEFAULT_MAXCALLING);
diff --git a/tdecachegrind/tdecachegrind/callgraphview.h b/tdecachegrind/tdecachegrind/callgraphview.h
index bb78af3b..8f99a706 100644
--- a/tdecachegrind/tdecachegrind/callgraphview.h
+++ b/tdecachegrind/tdecachegrind/callgraphview.h
@@ -426,8 +426,8 @@ public:
TQWidget* parent=0, const char* name=0);
~CallGraphView();
- void readViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
- void saveViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
+ void readViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
+ void saveViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
TQWidget* widget() { return this; }
TQString whatsThis() const;
diff --git a/tdecachegrind/tdecachegrind/callmapview.cpp b/tdecachegrind/tdecachegrind/callmapview.cpp
index 5af303f9..0bc70c7c 100644
--- a/tdecachegrind/tdecachegrind/callmapview.cpp
+++ b/tdecachegrind/tdecachegrind/callmapview.cpp
@@ -948,10 +948,10 @@ TQColor CallMapCallerItem::backColor() const
return w->groupColor(_c->caller());
}
-void CallMapView::readViewConfig(KConfig* c,
+void CallMapView::readViewConfig(TDEConfig* c,
TQString prefix, TQString postfix, bool)
{
- KConfigGroup* g = configGroup(c, prefix, postfix);
+ TDEConfigGroup* g = configGroup(c, prefix, postfix);
setSplitMode(g->readEntry("SplitMode", DEFAULT_SPLITMODE));
@@ -975,10 +975,10 @@ void CallMapView::readViewConfig(KConfig* c,
delete g;
}
-void CallMapView::saveViewConfig(KConfig* c,
+void CallMapView::saveViewConfig(TDEConfig* c,
TQString prefix, TQString postfix, bool)
{
- KConfigGroup g(c, (prefix+postfix).ascii());
+ TDEConfigGroup g(c, (prefix+postfix).ascii());
writeConfigEntry(&g, "SplitMode", splitModeString(), DEFAULT_SPLITMODE);
writeConfigEntry(&g, "DrawName", fieldVisible(0), DEFAULT_DRAWNAME);
diff --git a/tdecachegrind/tdecachegrind/callmapview.h b/tdecachegrind/tdecachegrind/callmapview.h
index 7518553e..d9ec69e3 100644
--- a/tdecachegrind/tdecachegrind/callmapview.h
+++ b/tdecachegrind/tdecachegrind/callmapview.h
@@ -41,8 +41,8 @@ public:
TQString whatsThis() const;
void setData(TraceData*);
- void readViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
- void saveViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
+ void readViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
+ void saveViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
bool showCallers() const { return _showCallers; }
TraceCost* totalCost();
diff --git a/tdecachegrind/tdecachegrind/configuration.cpp b/tdecachegrind/tdecachegrind/configuration.cpp
index 1455da45..b18440d2 100644
--- a/tdecachegrind/tdecachegrind/configuration.cpp
+++ b/tdecachegrind/tdecachegrind/configuration.cpp
@@ -130,12 +130,12 @@ Configuration* Configuration::config()
}
-void Configuration::saveOptions(KConfig* kconfig)
+void Configuration::saveOptions(TDEConfig* kconfig)
{
Configuration* c = config();
// color options
- KConfigGroup colorConfig(kconfig, TQCString("CostColors"));
+ TDEConfigGroup colorConfig(kconfig, TQCString("CostColors"));
TQDictIterator<ColorSetting> it( c->_colors );
int count = 1;
for( ; it.current(); ++it ) {
@@ -152,7 +152,7 @@ void Configuration::saveOptions(KConfig* kconfig)
colorConfig.writeEntry( "Count", count-1);
// source options
- KConfigGroup sourceConfig(kconfig, TQCString("Source"));
+ TDEConfigGroup sourceConfig(kconfig, TQCString("Source"));
sourceConfig.writeEntry("Dirs", c->_generalSourceDirs, ':');
TQDictIterator<TQStringList> it2( c->_objectSourceDirs );
count = 1;
@@ -166,7 +166,7 @@ void Configuration::saveOptions(KConfig* kconfig)
sourceConfig.writeEntry( "Count", count-1);
// general options
- KConfigGroup generalConfig(kconfig, TQCString("General"));
+ TDEConfigGroup generalConfig(kconfig, TQCString("General"));
generalConfig.writeEntry("ShowPercentage", c->_showPercentage);
generalConfig.writeEntry("ShowExpanded", c->_showExpanded);
generalConfig.writeEntry("ShowCycles", c->_showCycles);
@@ -179,7 +179,7 @@ void Configuration::saveOptions(KConfig* kconfig)
generalConfig.writeEntry("Context", c->_context);
generalConfig.writeEntry("NoCostInside", c->_noCostInside);
- KConfigGroup ctConfig(kconfig, TQCString("CostTypes"));
+ TDEConfigGroup ctConfig(kconfig, TQCString("CostTypes"));
int ctCount = TraceCostType::knownTypeCount();
ctConfig.writeEntry( "Count", ctCount);
for (int i=0; i<ctCount; i++) {
@@ -200,7 +200,7 @@ void Configuration::saveOptions(KConfig* kconfig)
-void Configuration::readOptions(KConfig* kconfig)
+void Configuration::readOptions(TDEConfig* kconfig)
{
int i, count;
Configuration* c = config();
@@ -226,7 +226,7 @@ void Configuration::readOptions(KConfig* kconfig)
c->color("CostType-Dr")->color = TQColor(40,40,180);
c->color("CostType-Dw")->color = TQColor(80,80,120);
- KConfigGroup colorConfig(kconfig, TQCString("CostColors"));
+ TDEConfigGroup colorConfig(kconfig, TQCString("CostColors"));
count = colorConfig.readNumEntry("Count", 0);
for (i=1;i<=count;i++) {
TQString n = colorConfig.readEntry(TQString("Name%1").arg(i));
@@ -245,7 +245,7 @@ void Configuration::readOptions(KConfig* kconfig)
}
// source options
- KConfigGroup sourceConfig(kconfig, TQCString("Source"));
+ TDEConfigGroup sourceConfig(kconfig, TQCString("Source"));
TQStringList dirs;
dirs = sourceConfig.readListEntry("Dirs", ':');
if (dirs.count()>0) c->_generalSourceDirs = dirs;
@@ -263,7 +263,7 @@ void Configuration::readOptions(KConfig* kconfig)
// general options
- KConfigGroup generalConfig(kconfig, TQCString("General"));
+ TDEConfigGroup generalConfig(kconfig, TQCString("General"));
c->_showPercentage = generalConfig.readBoolEntry("ShowPercentage", true);
c->_showExpanded = generalConfig.readBoolEntry("ShowExpanded", false);
c->_showCycles = generalConfig.readBoolEntry("ShowCycles", true);
@@ -279,7 +279,7 @@ void Configuration::readOptions(KConfig* kconfig)
// known cost types
if (TraceCostType::knownTypeCount()==0) {
- KConfigGroup ctConfig(kconfig, TQCString("CostTypes"));
+ TDEConfigGroup ctConfig(kconfig, TQCString("CostTypes"));
int ctCount = ctConfig.readNumEntry("Count", 0);
if (ctCount>0) {
for (int i=1;i<=ctCount;i++) {
diff --git a/tdecachegrind/tdecachegrind/configuration.h b/tdecachegrind/tdecachegrind/configuration.h
index 478f6176..b5f3bfbe 100644
--- a/tdecachegrind/tdecachegrind/configuration.h
+++ b/tdecachegrind/tdecachegrind/configuration.h
@@ -29,7 +29,7 @@
#include "tracedata.h"
-class KConfig;
+class TDEConfig;
class Configuration
{
@@ -40,8 +40,8 @@ public:
static Configuration* config();
- static void saveOptions(KConfig*);
- static void readOptions(KConfig*);
+ static void saveOptions(TDEConfig*);
+ static void readOptions(TDEConfig*);
// color for visualisation of an object
static TQColor functionColor(TraceItem::CostType gt, TraceFunction*);
diff --git a/tdecachegrind/tdecachegrind/instrview.cpp b/tdecachegrind/tdecachegrind/instrview.cpp
index ed3ad4de..5b819d6c 100644
--- a/tdecachegrind/tdecachegrind/instrview.cpp
+++ b/tdecachegrind/tdecachegrind/instrview.cpp
@@ -926,10 +926,10 @@ void InstrView::updateInstrItems()
}
}
-void InstrView::readViewConfig(KConfig* c,
+void InstrView::readViewConfig(TDEConfig* c,
TQString prefix, TQString postfix, bool)
{
- KConfigGroup* g = configGroup(c, prefix, postfix);
+ TDEConfigGroup* g = configGroup(c, prefix, postfix);
if (0) tqDebug("InstrView::readViewConfig");
@@ -938,10 +938,10 @@ void InstrView::readViewConfig(KConfig* c,
delete g;
}
-void InstrView::saveViewConfig(KConfig* c,
+void InstrView::saveViewConfig(TDEConfig* c,
TQString prefix, TQString postfix, bool)
{
- KConfigGroup g(c, (prefix+postfix).ascii());
+ TDEConfigGroup g(c, (prefix+postfix).ascii());
writeConfigEntry(&g, "ShowHexCode", _showHexCode, DEFAULT_SHOWHEXCODE);
}
diff --git a/tdecachegrind/tdecachegrind/instrview.h b/tdecachegrind/tdecachegrind/instrview.h
index 882f4e99..f5e847ad 100644
--- a/tdecachegrind/tdecachegrind/instrview.h
+++ b/tdecachegrind/tdecachegrind/instrview.h
@@ -42,8 +42,8 @@ public:
virtual TQWidget* widget() { return this; }
TQString whatsThis() const;
- void readViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
- void saveViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
+ void readViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
+ void saveViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
protected:
int arrowLevels() { return _arrowLevels; }
diff --git a/tdecachegrind/tdecachegrind/multiview.cpp b/tdecachegrind/tdecachegrind/multiview.cpp
index 53307c5c..9bf384b0 100644
--- a/tdecachegrind/tdecachegrind/multiview.cpp
+++ b/tdecachegrind/tdecachegrind/multiview.cpp
@@ -165,7 +165,7 @@ void MultiView::doUpdate(int changeType)
}
-void MultiView::readViewConfig(KConfig* c,
+void MultiView::readViewConfig(TDEConfig* c,
TQString prefix, TQString postfix,
bool withOptions)
{
@@ -173,7 +173,7 @@ void MultiView::readViewConfig(KConfig* c,
prefix.ascii(), postfix.ascii());
TQString active;
- KConfigGroup* g = configGroup(c, prefix, postfix);
+ TDEConfigGroup* g = configGroup(c, prefix, postfix);
int n = g->readNumEntry("Panels", 1);
setChildCount(n);
setOrientation( (g->readEntry("Orientation") == TQString("Horizontal")) ?
@@ -200,11 +200,11 @@ void MultiView::readViewConfig(KConfig* c,
activeTV->setActive(true);
}
-void MultiView::saveViewConfig(KConfig* c,
+void MultiView::saveViewConfig(TDEConfig* c,
TQString prefix, TQString postfix,
bool withOptions)
{
- KConfigGroup g(c, (prefix+postfix).ascii());
+ TDEConfigGroup g(c, (prefix+postfix).ascii());
g.writeEntry("Panels", childCount());
g.writeEntry("Orientation",
diff --git a/tdecachegrind/tdecachegrind/multiview.h b/tdecachegrind/tdecachegrind/multiview.h
index 9b739c14..c5d4d81f 100644
--- a/tdecachegrind/tdecachegrind/multiview.h
+++ b/tdecachegrind/tdecachegrind/multiview.h
@@ -51,8 +51,8 @@ public:
void selected(TraceItemView*, TraceItem*);
void activated(TraceItemView*, TraceItem*);
- void readViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
- void saveViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
+ void readViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
+ void saveViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
public slots:
void tabActivated(TabView*);
diff --git a/tdecachegrind/tdecachegrind/partselection.cpp b/tdecachegrind/tdecachegrind/partselection.cpp
index 8acef22b..4f30e1fe 100644
--- a/tdecachegrind/tdecachegrind/partselection.cpp
+++ b/tdecachegrind/tdecachegrind/partselection.cpp
@@ -461,7 +461,7 @@ void PartSelection::hiddenPartsChangedSlot(const TracePartList& list)
partAreaWidget->changeHidden(list);
}
-void PartSelection::readVisualisationConfig(KConfigGroup* config)
+void PartSelection::readVisualisationConfig(TDEConfigGroup* config)
{
bool enable;
@@ -500,7 +500,7 @@ void PartSelection::readVisualisationConfig(KConfigGroup* config)
showInfo(config->readBoolEntry("ShowInfo", false));
}
-void PartSelection::saveVisualisationConfig(KConfigGroup* config)
+void PartSelection::saveVisualisationConfig(TDEConfigGroup* config)
{
TQString mode;
if (partAreaWidget->visualisation() == PartAreaWidget::Inclusive)
diff --git a/tdecachegrind/tdecachegrind/partselection.h b/tdecachegrind/tdecachegrind/partselection.h
index 974fa585..4313d0d8 100644
--- a/tdecachegrind/tdecachegrind/partselection.h
+++ b/tdecachegrind/tdecachegrind/partselection.h
@@ -30,7 +30,7 @@
#include "partgraph.h"
#include "tracedata.h"
-class KConfigGroup;
+class TDEConfigGroup;
class TraceFunction;
class TraceData;
class TreeMapItem;
@@ -49,8 +49,8 @@ public:
PartAreaWidget* graph() { return partAreaWidget; }
- void readVisualisationConfig(KConfigGroup*);
- void saveVisualisationConfig(KConfigGroup*);
+ void readVisualisationConfig(TDEConfigGroup*);
+ void saveVisualisationConfig(TDEConfigGroup*);
signals:
void activePartsChanged(const TracePartList& list);
diff --git a/tdecachegrind/tdecachegrind/tabview.cpp b/tdecachegrind/tdecachegrind/tabview.cpp
index a194ddb4..2c38aa4b 100644
--- a/tdecachegrind/tdecachegrind/tabview.cpp
+++ b/tdecachegrind/tdecachegrind/tabview.cpp
@@ -709,14 +709,14 @@ void TabView::selected(TraceItemView*, TraceItem* s)
}
-void TabView::readViewConfig(KConfig* c,
+void TabView::readViewConfig(TDEConfig* c,
TQString prefix, TQString postfix,
bool withOptions)
{
if (0) tqDebug("%s::readConfig(%s%s)", name(),
prefix.ascii(), postfix.ascii());
- KConfigGroup* g = configGroup(c, prefix, postfix);
+ TDEConfigGroup* g = configGroup(c, prefix, postfix);
_mainSplitter->setSizes(g->readIntListEntry("MainSizes"));
_leftSplitter->setSizes(g->readIntListEntry("LeftSizes"));
@@ -806,11 +806,11 @@ void TabView::readViewConfig(KConfig* c,
updateView();
}
-void TabView::saveViewConfig(KConfig* c,
+void TabView::saveViewConfig(TDEConfig* c,
TQString prefix, TQString postfix,
bool withOptions)
{
- KConfigGroup g(c, (prefix+postfix).ascii());
+ TDEConfigGroup g(c, (prefix+postfix).ascii());
g.writeEntry("MainSizes", _mainSplitter->sizes());
g.writeEntry("LeftSizes", _leftSplitter->sizes());
diff --git a/tdecachegrind/tdecachegrind/tabview.h b/tdecachegrind/tdecachegrind/tabview.h
index cbca5aa4..19c52297 100644
--- a/tdecachegrind/tdecachegrind/tabview.h
+++ b/tdecachegrind/tdecachegrind/tabview.h
@@ -135,8 +135,8 @@ public:
int visibleTabs();
int visibleAreas();
- void readViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
- void saveViewConfig(KConfig*, TQString prefix, TQString postfix, bool);
+ void readViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
+ void saveViewConfig(TDEConfig*, TQString prefix, TQString postfix, bool);
public slots:
void tabChanged(TQWidget*);
diff --git a/tdecachegrind/tdecachegrind/toplevel.h b/tdecachegrind/tdecachegrind/toplevel.h
index 4db0bc09..7ac4f2de 100644
--- a/tdecachegrind/tdecachegrind/toplevel.h
+++ b/tdecachegrind/tdecachegrind/toplevel.h
@@ -64,8 +64,8 @@ public:
TraceData* data() { return _data; }
void setData(TraceData*);
- virtual void saveProperties(KConfig*);
- virtual void readProperties(KConfig*);
+ virtual void saveProperties(TDEConfig*);
+ virtual void readProperties(TDEConfig*);
void createActions();
void createDocks();
diff --git a/tdecachegrind/tdecachegrind/traceitemview.cpp b/tdecachegrind/tdecachegrind/traceitemview.cpp
index d11f02b6..8df7297f 100644
--- a/tdecachegrind/tdecachegrind/traceitemview.cpp
+++ b/tdecachegrind/tdecachegrind/traceitemview.cpp
@@ -58,15 +58,15 @@ void TraceItemView::select(TraceItem* i)
_newSelectedItem = i;
}
-KConfigGroup* TraceItemView::configGroup(KConfig* c,
+TDEConfigGroup* TraceItemView::configGroup(TDEConfig* c,
TQString group, TQString post)
{
TQStringList gList = c->groupList();
if (gList.contains((group+post).ascii()) ) group += post;
- return new KConfigGroup(c, group);
+ return new TDEConfigGroup(c, group);
}
-void TraceItemView::writeConfigEntry(KConfigBase* c, const char* pKey,
+void TraceItemView::writeConfigEntry(TDEConfigBase* c, const char* pKey,
TQString value, const char* def, bool bNLS)
{
if (!c) return;
@@ -77,7 +77,7 @@ void TraceItemView::writeConfigEntry(KConfigBase* c, const char* pKey,
c->writeEntry(pKey, value, true, false, bNLS);
}
-void TraceItemView::writeConfigEntry(KConfigBase* c, const char* pKey,
+void TraceItemView::writeConfigEntry(TDEConfigBase* c, const char* pKey,
int value, int def)
{
if (!c) return;
@@ -87,7 +87,7 @@ void TraceItemView::writeConfigEntry(KConfigBase* c, const char* pKey,
c->writeEntry(pKey, value);
}
-void TraceItemView::writeConfigEntry(KConfigBase* c, const char* pKey,
+void TraceItemView::writeConfigEntry(TDEConfigBase* c, const char* pKey,
double value, double def)
{
if (!c) return;
@@ -97,7 +97,7 @@ void TraceItemView::writeConfigEntry(KConfigBase* c, const char* pKey,
c->writeEntry(pKey, value);
}
-void TraceItemView::writeConfigEntry(KConfigBase* c, const char* pKey,
+void TraceItemView::writeConfigEntry(TDEConfigBase* c, const char* pKey,
bool value, bool def)
{
if (!c) return;
@@ -107,18 +107,18 @@ void TraceItemView::writeConfigEntry(KConfigBase* c, const char* pKey,
c->writeEntry(pKey, value);
}
-void TraceItemView::readViewConfig(KConfig*, TQString, TQString, bool)
+void TraceItemView::readViewConfig(TDEConfig*, TQString, TQString, bool)
{}
#if 1
-void TraceItemView::saveViewConfig(KConfig*, TQString, TQString, bool)
+void TraceItemView::saveViewConfig(TDEConfig*, TQString, TQString, bool)
{}
#else
-void TraceItemView::saveViewConfig(KConfig* c,
+void TraceItemView::saveViewConfig(TDEConfig* c,
TQString prefix, TQString postfix, bool)
{
// write a dummy config entry to see missing virtual functions
- KConfigGroup g(c, (prefix+postfix).ascii());
+ TDEConfigGroup g(c, (prefix+postfix).ascii());
g.writeEntry("SaveNotImplemented", true);
}
#endif
diff --git a/tdecachegrind/tdecachegrind/traceitemview.h b/tdecachegrind/tdecachegrind/traceitemview.h
index f83aa896..aad2b145 100644
--- a/tdecachegrind/tdecachegrind/traceitemview.h
+++ b/tdecachegrind/tdecachegrind/traceitemview.h
@@ -28,9 +28,9 @@
class TQWidget;
class TQPopupMenu;
-class KConfig;
-class KConfigGroup;
-class KConfigBase;
+class TDEConfig;
+class TDEConfigGroup;
+class TDEConfigBase;
class TopLevel;
@@ -74,18 +74,18 @@ public:
virtual TQString whatsThis() const;
- static KConfigGroup* configGroup(KConfig*, TQString prefix, TQString postfix);
- static void writeConfigEntry(KConfigBase*, const char* pKey, TQString value,
+ static TDEConfigGroup* configGroup(TDEConfig*, TQString prefix, TQString postfix);
+ static void writeConfigEntry(TDEConfigBase*, const char* pKey, TQString value,
const char* def, bool bNLS = false);
- static void writeConfigEntry(KConfigBase*, const char* pKey,
+ static void writeConfigEntry(TDEConfigBase*, const char* pKey,
int value, int def);
- static void writeConfigEntry(KConfigBase*, const char* pKey,
+ static void writeConfigEntry(TDEConfigBase*, const char* pKey,
bool value, bool def);
- static void writeConfigEntry(KConfigBase*, const char* pKey,
+ static void writeConfigEntry(TDEConfigBase*, const char* pKey,
double value, double def);
- virtual void readViewConfig(KConfig*, TQString prefix, TQString postfix,
+ virtual void readViewConfig(TDEConfig*, TQString prefix, TQString postfix,
bool withOptions);
- virtual void saveViewConfig(KConfig*, TQString prefix, TQString postfix,
+ virtual void saveViewConfig(TDEConfig*, TQString prefix, TQString postfix,
bool withOptions);
// Immediate remove all references to old data, and set the new.
diff --git a/tdecachegrind/tdecachegrind/treemap.cpp b/tdecachegrind/tdecachegrind/treemap.cpp
index 0d4b8dc9..fe5965b2 100644
--- a/tdecachegrind/tdecachegrind/treemap.cpp
+++ b/tdecachegrind/tdecachegrind/treemap.cpp
@@ -3132,7 +3132,7 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
* Option saving/restoring
*/
-void TreeMapWidget::saveOptions(KConfigGroup* config, TQString prefix)
+void TreeMapWidget::saveOptions(TDEConfigGroup* config, TQString prefix)
{
config->writeEntry(prefix+"Nesting", splitModeString());
config->writeEntry(prefix+"AllowRotation", allowRotation());
@@ -3157,7 +3157,7 @@ void TreeMapWidget::saveOptions(KConfigGroup* config, TQString prefix)
}
-void TreeMapWidget::restoreOptions(KConfigGroup* config, TQString prefix)
+void TreeMapWidget::restoreOptions(TDEConfigGroup* config, TQString prefix)
{
bool enabled;
int num;
diff --git a/tdecachegrind/tdecachegrind/treemap.h b/tdecachegrind/tdecachegrind/treemap.h
index 0b494d8f..e7f99801 100644
--- a/tdecachegrind/tdecachegrind/treemap.h
+++ b/tdecachegrind/tdecachegrind/treemap.h
@@ -46,7 +46,7 @@ class TreeMapItem;
class TreeMapItemList;
class TQString;
-class KConfigGroup;
+class TDEConfigGroup;
/**
@@ -614,8 +614,8 @@ public:
/**
* Save/restore options.
*/
- void saveOptions(KConfigGroup*, TQString prefix = TQString());
- void restoreOptions(KConfigGroup*, TQString prefix = TQString());
+ void saveOptions(TDEConfigGroup*, TQString prefix = TQString());
+ void restoreOptions(TDEConfigGroup*, TQString prefix = TQString());
/**
* These functions populate given popup menus.
diff --git a/tdecachegrind/tdecachegrind/toplevel.cpp b/tdecachegrind/tdecachegrind/toplevel.cpp
index 6364e53c..bb9db209 100644
--- a/tdecachegrind/tdecachegrind/toplevel.cpp
+++ b/tdecachegrind/tdecachegrind/toplevel.cpp
@@ -105,7 +105,7 @@ TopLevel::TopLevel(const char *name)
#endif
_statusbar->addWidget(_statusLabel, 1);
- KConfig* kconfig = TDEGlobal::config();
+ TDEConfig* kconfig = TDEGlobal::config();
Configuration::readOptions( kconfig );
_openRecent->loadEntries( kconfig );
@@ -201,13 +201,13 @@ void TopLevel::setupPartSelection(PartSelection* ps)
*/
void TopLevel::saveCurrentState(TQString postfix)
{
- KConfig* kconfig = TDEGlobal::config();
+ TDEConfig* kconfig = TDEGlobal::config();
TQCString pf = postfix.ascii();
- KConfigGroup psConfig(kconfig, TQCString("PartOverview")+pf);
+ TDEConfigGroup psConfig(kconfig, TQCString("PartOverview")+pf);
_partSelection->saveVisualisationConfig(&psConfig);
- KConfigGroup stateConfig(kconfig, TQCString("CurrentState")+pf);
+ TDEConfigGroup stateConfig(kconfig, TQCString("CurrentState")+pf);
stateConfig.writeEntry("CostType",
_costType ? _costType->name() : TQString("?"));
stateConfig.writeEntry("CostType2",
@@ -225,7 +225,7 @@ void TopLevel::saveTraceSettings()
{
TQString key = traceKey();
- KConfigGroup pConfig(TDEGlobal::config(), TQCString("TracePositions"));
+ TDEConfigGroup pConfig(TDEGlobal::config(), TQCString("TracePositions"));
pConfig.writeEntry(TQString("CostType%1").arg(key),
_costType ? _costType->name() : TQString("?"));
pConfig.writeEntry(TQString("CostType2%1").arg(key),
@@ -235,7 +235,7 @@ void TopLevel::saveTraceSettings()
if (!_data) return;
- KConfigGroup aConfig(TDEGlobal::config(), TQCString("Layouts"));
+ TDEConfigGroup aConfig(TDEGlobal::config(), TQCString("Layouts"));
aConfig.writeEntry(TQString("Count%1").arg(key), _layoutCount);
aConfig.writeEntry(TQString("Current%1").arg(key), _layoutCurrent);
@@ -253,14 +253,14 @@ void TopLevel::saveTraceSettings()
*/
void TopLevel::restoreCurrentState(TQString postfix)
{
- KConfig* kconfig = TDEGlobal::config();
+ TDEConfig* kconfig = TDEGlobal::config();
TQStringList gList = kconfig->groupList();
TQCString pf = postfix.ascii();
// dock properties (not position, this should be have done before)
TQCString group = TQCString("PartOverview");
if (gList.contains(group+pf)) group += pf;
- KConfigGroup psConfig(kconfig, group);
+ TDEConfigGroup psConfig(kconfig, group);
_partSelection->readVisualisationConfig(&psConfig);
_multiView->readViewConfig(kconfig, TQString("MainView"), postfix, true);
@@ -388,7 +388,7 @@ void TopLevel::createDocks()
#endif
// Restore QT Dock positions...
- KConfigGroup dockConfig(TDEGlobal::config(), TQCString("Docks"));
+ TDEConfigGroup dockConfig(TDEGlobal::config(), TQCString("Docks"));
TQString str = dockConfig.readEntry("Position", TQString());
if (0) tqDebug("Docks/Position: '%s'", str.ascii());
if (str.isEmpty()) {
@@ -427,12 +427,12 @@ TopLevel::~TopLevel()
}
-void TopLevel::saveProperties(KConfig* c)
+void TopLevel::saveProperties(TDEConfig* c)
{
c->writeEntry("TraceName", _data->traceName());
}
-void TopLevel::readProperties(KConfig* c)
+void TopLevel::readProperties(TDEConfig* c)
{
TQString traceName = c->readEntry("TraceName");
if (!traceName.isEmpty()) {
@@ -1017,16 +1017,16 @@ void TopLevel::loadTrace(const KURL& url)
// network transparancy
TQString tmpFile;
#if TDE_VERSION > 0x030190
- // for KDE 3.2: KIO::NetAccess::download with 2 args is deprecated
- if(KIO::NetAccess::download( url, tmpFile, this )) {
+ // for KDE 3.2: TDEIO::NetAccess::download with 2 args is deprecated
+ if(TDEIO::NetAccess::download( url, tmpFile, this )) {
#else
- if(KIO::NetAccess::download( url, tmpFile )) {
+ if(TDEIO::NetAccess::download( url, tmpFile )) {
#endif
_openRecent->addURL(url);
_openRecent->saveEntries( TDEGlobal::config() );
loadTrace(tmpFile);
- KIO::NetAccess::removeTempFile( tmpFile );
+ TDEIO::NetAccess::removeTempFile( tmpFile );
}
}
@@ -1066,16 +1066,16 @@ void TopLevel::addTrace(const KURL& url)
// network transparancy
TQString tmpFile;
#if TDE_VERSION > 0x030190
- // for KDE 3.2: KIO::NetAccess::download with 2 args is deprecated
- if(KIO::NetAccess::download( url, tmpFile, this )) {
+ // for KDE 3.2: TDEIO::NetAccess::download with 2 args is deprecated
+ if(TDEIO::NetAccess::download( url, tmpFile, this )) {
#else
- if(KIO::NetAccess::download( url, tmpFile )) {
+ if(TDEIO::NetAccess::download( url, tmpFile )) {
#endif
_openRecent->addURL(url);
_openRecent->saveEntries( TDEGlobal::config() );
addTrace(tmpFile);
- KIO::NetAccess::removeTempFile( tmpFile );
+ TDEIO::NetAccess::removeTempFile( tmpFile );
}
}
@@ -1721,8 +1721,8 @@ void TopLevel::restoreTraceTypes()
{
TQString key = traceKey();
- KConfigGroup cConfig(TDEGlobal::config(), TQCString("CurrentState"));
- KConfigGroup pConfig(TDEGlobal::config(), TQCString("TracePositions"));
+ TDEConfigGroup cConfig(TDEGlobal::config(), TQCString("CurrentState"));
+ TDEConfigGroup pConfig(TDEGlobal::config(), TQCString("TracePositions"));
TQString groupType, costType, costType2;
groupType = pConfig.readEntry(TQString("GroupType%1").arg(key));
@@ -1741,7 +1741,7 @@ void TopLevel::restoreTraceTypes()
if (!_costType && !_saCost->items().isEmpty())
costTypeSelected(_saCost->items().first());
- KConfigGroup aConfig(TDEGlobal::config(), TQCString("Layouts"));
+ TDEConfigGroup aConfig(TDEGlobal::config(), TQCString("Layouts"));
_layoutCount = aConfig.readNumEntry(TQString("Count%1").arg(key), 0);
_layoutCurrent = aConfig.readNumEntry(TQString("Current%1").arg(key), 0);
if (_layoutCount == 0) layoutRestore();
@@ -1760,7 +1760,7 @@ void TopLevel::restoreTraceSettings()
TQString key = traceKey();
- KConfigGroup pConfig(TDEGlobal::config(), TQCString("TracePositions"));
+ TDEConfigGroup pConfig(TDEGlobal::config(), TQCString("TracePositions"));
TQString group = pConfig.readEntry(TQString("Group%1").arg(key));
if (!group.isEmpty()) setGroup(group);
@@ -1811,7 +1811,7 @@ void TopLevel::layoutNext()
{
if (_layoutCount <2) return;
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
TQString key = traceKey();
_multiView->saveViewConfig(config,
@@ -1832,7 +1832,7 @@ void TopLevel::layoutPrevious()
{
if (_layoutCount <2) return;
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
TQString key = traceKey();
_multiView->saveViewConfig(config,
@@ -1851,7 +1851,7 @@ void TopLevel::layoutPrevious()
void TopLevel::layoutSave()
{
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
TQString key = traceKey();
_multiView->saveViewConfig(config,
@@ -1871,15 +1871,15 @@ void TopLevel::layoutSave()
TQString("Layout%1-MainView").arg(_layoutCurrent),
key, false);
- KConfigGroup aConfig(config, TQCString("Layouts"));
+ TDEConfigGroup aConfig(config, TQCString("Layouts"));
aConfig.writeEntry("DefaultCount", _layoutCount);
aConfig.writeEntry("DefaultCurrent", _layoutCurrent);
}
void TopLevel::layoutRestore()
{
- KConfig* config = TDEGlobal::config();
- KConfigGroup aConfig(config, TQCString("Layouts"));
+ TDEConfig* config = TDEGlobal::config();
+ TDEConfigGroup aConfig(config, TQCString("Layouts"));
_layoutCount = aConfig.readNumEntry("DefaultCount", 0);
_layoutCurrent = aConfig.readNumEntry("DefaultCurrent", 0);
if (_layoutCount == 0) {
@@ -1994,7 +1994,7 @@ bool TopLevel::queryExit()
// Its already stored.
delete toolBar();
- KConfigGroup dockConfig(TDEGlobal::config(), TQCString("Docks"));
+ TDEConfigGroup dockConfig(TDEGlobal::config(), TQCString("Docks"));
TQString str;
TQTextStream ts( &str, IO_WriteOnly );
ts << *this;